@@ -54,7 +54,7 @@ class Grid(SquareGameGrid):
         self.empty_cells: Set[Cell] = set(self.cells())
         self.reset(first=True)
 
-    cells = values
+    cells = SquareGameGrid.values
 
     def reset(self, first: bool = False) -> None:
         self.attempt = 0
